insert method

Future<List<ChatMessage>> insert(
  1. Session session,
  2. List<ChatMessage> rows, {
  3. Transaction? transaction,
})

Inserts all ChatMessages in the list and returns the inserted rows.

The returned ChatMessages will have their id fields set.

This is an atomic operation, meaning that if one of the rows fails to insert, none of the rows will be inserted.

Implementation

Future<List<ChatMessage>> insert(
  _i1.Session session,
  List<ChatMessage> rows, {
  _i1.Transaction? transaction,
}) async {
  return session.db.insert<ChatMessage>(
    rows,
    transaction: transaction,
  );
}